==> ironjacamar-core-impl-1.0.11.Final-sources.jar: org/jboss/jca/Version.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.jca;

/**
 * The version class
 * @author Jesper Pedersen <jesper.pedersen@jboss.org>
 */
public class Version
{
   /** The vendor */
   public static final String VENDOR = "JBoss"; 
   
   /** The product */
   public static final String PRODUCT = "IronJacamar"; 
   
   /** The version */
   public static final String VERSION = "1.0.11.Final";
   
   /** Full version */
   public static final String FULL_VERSION = VENDOR + " " + PRODUCT + " " + VERSION;
   
   /**
    * Constructor
    */
   private Version()
   {
   }

   /**
    * Main
    * @param args The arguments
    */
   public static void main(String[] args)
   {
      System.out.println(PRODUCT + " " + VERSION);
   }
}

==> ironjacamar-core-impl-1.4.20.Final-sources.jar: org/jboss/jca/Version.java <==
/*
 * IronJacamar, a Java EE Connector Architecture implementation
 * Copyright 2013, Red Hat Inc, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.jca;

/**
 * The version class
 * @author <a href="mailto:jesper.pedersen@ironjacamar.org">Jesper Pedersen</a>
 */
public class Version
{
   /** The project */
   public static final String PROJECT = "WildFly/IronJacamar"; 
   
   /** The version */
   public static final String VERSION = "1.4.20.Final";
   
   /** Full version */
   public static final String FULL_VERSION = PROJECT + " " + VERSION;
   
   /**
    * Constructor
    */
   private Version()
   {
   }

   /**
    * Main
    * @param args The arguments
    */
   public static void main(String[] args)
   {
      System.out.println(FULL_VERSION);
   }
}
